@@ -1,4 +1,5 @@
 from ._version import __version__
+from fileformats.core import import_converters
 from .base import MedicalImage, NeuroImage
 from .misc import (  # noqa: F401
     Analyze,
@@ -30,16 +31,8 @@ from .raw import (  # noqa: F401
     ListMode,
     Kspace,
     TwixVb,
-    CustomKspace,
+    # CustomKspace,
     Rda,
 )
 
-try:
-    import fileformats.medimage.converters
-except ImportError:
-    from warnings import warn
-    warn(
-        f"could not import converters for {__name__}  module, please install "
-        "fileformats-medimage[converters] package if converters are desired"
-    )
-
+import_converters(__name__)
